@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 12064 2020-04-10 07:49:46Z Lavender $
+# $Id: setup.py 12088 2020-04-17 09:49:03Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-10 15:49:46 +0800 (週五, 10 四月 2020) $
-# $Revision: 12064 $
+# $Date: 2020-04-17 17:49:03 +0800 (週五, 17 四月 2020) $
+# $Revision: 12088 $
 
 import re
 import os
@@ -503,6 +503,13 @@ if __name__ == "__main__":
         
         checkVersion()
         
+        if os.path.exists(os.path.join(SETUP_DIR, 'cms')):
+            logger.error(colored(
+                "In order to use this setup.py normally, the current folder cannot have a folder named 'cms'.", 
+                "red", attrs=['bold']
+            ))
+            sys.exit(0)
+        
         try:
             if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
                 with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
