@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12011 2020-03-25 11:01:56Z Lavender $
+# $Id: models.py 12044 2020-04-05 11:36:35Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-25 19:01:56 +0800 (週三, 25 三月 2020) $
-# $Revision: 12011 $
+# $Date: 2020-04-05 19:36:35 +0800 (週日, 05 四月 2020) $
+# $Revision: 12044 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -29,7 +29,7 @@ class FacebookSettings(SingletonModel):
 
 class FacebookFan(CMSPlugin):
     url = models.URLField(_("Facebook fan page URL"), max_length=400)
-    limit = models.PositiveIntegerField(default=0, 
+    limit = models.PositiveIntegerField(_("Number of articles"), default=0, 
         validators=[MaxValueValidator(20),])
 
     renderTemplate = models.CharField(
@@ -59,7 +59,7 @@ class FacebookFan(CMSPlugin):
     
 class FacebookPhoto(CMSPlugin):
     url = models.URLField(_("Facebook fan page album URL"), max_length=400)
-    limit = models.PositiveIntegerField(default=0,
+    limit = models.PositiveIntegerField(_("Number of photos"), default=0,
         validators=[MaxValueValidator(20),])
     renderTemplate = models.CharField(
         _('Photo Template'), max_length=150, blank=True,
